import { Observable } from 'rxjs';
export declare const enum ExtensionSortOrder {
    DEFAULT = 0,
    UNDO_EXTENSION = 1
}
export declare type AppState = Record<string, any>;
export declare abstract class StoreExtension {
    sortOrder: ExtensionSortOrder;
    abstract init(): void;
}
export interface Action {
    type: string;
    [x: string]: any;
}
export interface ActionWithPayload extends Action {
    payload?: any;
}
export interface StoreConfig<T> {
    reducers: ReducerDictionary<T>;
    initialState: T;
    metaReducers: MetaReducer<AppState>[];
    extensions: StoreExtension[];
}
export interface FeatureConfig<StateType> {
    initialState: StateType;
    metaReducers?: MetaReducer<StateType>[];
}
export interface FeatureStoreConfig {
    multi?: boolean;
}
export declare class Actions extends Observable<Action> {
}
export declare type Reducer<StateType> = (state: StateType, action: Action) => StateType;
export declare type MetaReducer<StateType> = (reducer: Reducer<StateType>) => Reducer<StateType>;
export declare type ReducerDictionary<T> = {
    [p in keyof T]: Reducer<T[p]>;
};
export declare type StateOrCallback<StateType> = Partial<StateType> | ((state: StateType) => Partial<StateType>);
export declare const EFFECT_METADATA_KEY = "@mini-rx/effectMetaData";
export interface EffectConfig {
    /**
     * Determines if the action emitted by the effect is dispatched to the store.
     * If false, effect does not need to return type `Observable<Action>`.
     */
    dispatch?: boolean;
}
export interface HasEffectMetadata {
    [EFFECT_METADATA_KEY]: EffectConfig;
}
